SEAPY Model Package Documentation
=================================

:mod:`seapy.model` -- Methods for working with general ocean models
*******************************************************************


.. automodule:: seapy.model.__init__
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seapy.model.lib
   :members:
   :undoc-members:
   :show-inheritance:



:mod:`grid` -- Collect grid information about a model
-----------------------------------------------------
.. automodule:: seapy.model.grid
  :noindex:

.. autoclass:: seapy.model.grid
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`hycom` -- Download HYCOM data for a given region/time
-----------------------------------------------------------
.. automodule:: seapy.model.hycom
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`soda` -- Download SODA data for a given region/time
---------------------------------------------------------
.. automodule:: seapy.model.soda
   :members:
   :undoc-members:
   :show-inheritance:

